/*
** Module   : HintsConstants.java
** Abstract : UAST hints constants used in XML grammar
**
** Copyright (c) 2005-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -T- --JPRM-- ----------------Description-----------------
** 001 GES 20050204 NEW   @19621 Created initial version with appropriate
**                               constants for both database loading and
**                               passing runtime arguments to the 
**                               preprocessor.
** 002 GES 20050210 CHG   @19748 Added support for aliases, variables and
**                               widgets (includes frames too).
** 003 GES 20050314 CHG   @20322 Added support for generic UAST hints of
**                               string, string array, boolean, long and
**                               double types.  Each one has a unique name
**                               that is used as a key to lookup the value.
** 004 ECF 20050713 CHG   @21698 Added ELEM_SCHEMA and ELEM_TABLE. Used for
**                               the schema hints sub-hierarchy.
** 005 GES 20070313 CHG   @32397 Added ELEM_PROPATH.
** 006 GES 20070403 CHG   @32715 Added ELEM_ESC.
** 007 GES 20070423 CHG   @33208 Added ELEM_MARKER.
** 008 GES 20070816 CHG   @34890 Added ELEM_OPSYS, ELEM_BATCH and ELEM_WINSYS.
** 009 GES 20070904 CHG   @34949 Added ELEM_E4GL, ELEM_WSOPTIONS, ELEM_MODE
**                               and ELEM_OUTPUT.
** 010 GES 20070919 CHG   @35136 Added ATTR_CLASSNAME.
** 011 GES 20080324 CHG   @37662 Added ATTR_POS and changed ELEM_ARGS to
**                               ELEM_ARG.
** 012 GES 20081007 CHG   @40355 Added ELEM_BASEPATH.
** 013 VMN 20140413              Added ATTR_ESCAPE.
*/

package com.goldencode.p2j.uast;

/**
 * Constant values for the XML grammar used for hints.
 *
 * @author    GES
 */
public interface HintsConstants
{
   /** Database element tag name. */
   public static final String ELEM_DATABASE = "database";
   
   /** Preprocessor element tag name. */
   public static final String ELEM_PREPROC = "preprocessor";
   
   /** Arguments element tag name. */
   public static final String ELEM_ARG = "argument";
   
   /** Honor UNIX escape sequences element tag name. */
   public static final String ELEM_ESC = "unix-escapes";
   
   /** Preprocessor marker element tag name. */
   public static final String ELEM_MARKER = "marker";
   
   /** Preprocessor BATCH-MODE element tag name. */
   public static final String ELEM_BATCH = "batch";
   
   /** Preprocessor OPSYS element tag name. */
   public static final String ELEM_OPSYS = "opsys";
   
   /** Preprocessor WINDOW-SYSTEM element tag name. */
   public static final String ELEM_WINSYS = "winsys";
   
   /** Alias element tag name. */
   public static final String ELEM_ALIAS = "alias";
   
   /** Variable element tag name. */
   public static final String ELEM_VAR = "variable";
   
   /** <code>PROPATH</code> customization element tag. */
   public static final String ELEM_PROPATH = "propath";      
   
   /** Root element tag name of schema sub-hierarchy */
   public static final String ELEM_SCHEMA = "schema";
   
   /** Table element tag name */
   public static final String ELEM_TABLE = "table";
   
   /** Generic UAST hint element tag name. */
   public static final String ELEM_UAST = "uast";
   
   /** Generic UAST hint element array value tag name. */
   public static final String ELEM_ARRAY = "array-val";
   
   /** Generic UAST hint element e4gl tag name. */
   public static final String ELEM_E4GL = "e4gl";
   
   /** Generic UAST hint element wsoptions tag name. */
   public static final String ELEM_WSOPTIONS = "wsoptions";
   
   /** Generic UAST hint element mode tag name. */
   public static final String ELEM_MODE = "wsmode";
   
   /** Generic UAST hint element output tag name. */
   public static final String ELEM_OUTPUT = "output";
   
   /** Generic UAST hint element basepath tag name. */
   public static final String ELEM_BASEPATH = "basepath";
   
   /** Name attribute used in multiple elements. */
   public static final String ATTR_NAME = "name";
   
   /** Value attribute used in multiple elements. */
   public static final String ATTR_VAL = "value";   
   
   /** Database attribute used in alias elements. */
   public static final String ATTR_DB = "database";   
   
   /** Token type attribute used in variable/widget elements. */
   public static final String ATTR_TYPE = "type";   
   
   /** Class name attribute used in variable/widget elements. */
   public static final String ATTR_CLASSNAME = "classname";
   
   /** Data type attribute used in UAST elements. */
   public static final String ATTR_DTYPE = "datatype";

   /** Escape attribute used in schema/table/field elements. */
   public static final String ATTR_ESCAPE = "escape";

   /** Positional number used in preprocessor arguments. */
   public static final String ATTR_POS = "pos";      
}
